@@ -1,7 +1,5 @@
 package WWW::FetchStory::Fetcher;
-{
-  $WWW::FetchStory::Fetcher::VERSION = '0.1822';
-}
+$WWW::FetchStory::Fetcher::VERSION = '0.1823';
 use strict;
 use warnings;
 =head1 NAME
@@ -10,7 +8,7 @@ WWW::FetchStory::Fetcher - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1822
+version 0.1823
 
 =head1 DESCRIPTION
 
@@ -99,7 +97,7 @@ sub init {
 		hide_cookie2 => 1,
 		ignore_discard => 1,
 	    );
-	    print "\n--------------\n", $cookies->as_string, "\n------------\n" if $self->{debug};
+	    print "\n--------------\n", $cookies->as_string, "\n------------\n" if ($self->{debug} && $self->{debug} > 1);
 	    $self->{user_agent}->cookie_jar( $cookies );
 	}
 	elsif ($self->{wget_cookies} and -f $self->{wget_cookies})
@@ -109,7 +107,7 @@ sub init {
 		hide_cookie2 => 1,
 		ignore_discard => 1,
 	    );
-	    print "\n--------------\n", $cookies->as_string, "\n------------\n" if $self->{debug};
+	    print "\n--------------\n", $cookies->as_string, "\n------------\n" if ($self->{debug} && $self->{debug} > 1);
 	    $self->{user_agent}->cookie_jar( $cookies );
 	}
 	if ($self->{debug})
