@@ -1,7 +1,5 @@
 package WWW::FetchStory::Fetcher::AO3;
-{
-  $WWW::FetchStory::Fetcher::AO3::VERSION = '0.1822';
-}
+$WWW::FetchStory::Fetcher::AO3::VERSION = '0.1823';
 use strict;
 use warnings;
 =head1 NAME
@@ -10,7 +8,7 @@ WWW::FetchStory::Fetcher::AO3 - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1822
+version 0.1823
 
 =head1 DESCRIPTION
 
@@ -311,7 +309,18 @@ sub parse_characters {
     my $content = $args{content};
 
     my $characters = '';
-    if ($content =~ m!^Characters: (.*?)$!m)
+    if ($content =~ m!<dd class="character tags">(.*?)</dd>!s)
+    {
+        # multiple characters inside links
+        my $str = $1;
+        my @chars = ();
+        while ($str =~ m!([^><]+)</a>!g)
+        {
+            push @chars, $1;
+        }
+        $characters = join(', ', @chars);
+    }
+    elsif ($content =~ m!^Characters: (.*?)$!m)
     {
 	$characters = $1;
     }
