@@ -1,7 +1,5 @@
 package WWW::FetchStory::Fetcher::LiveJournal;
-{
-  $WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1822';
-}
+$WWW::FetchStory::Fetcher::LiveJournal::VERSION = '0.1823';
 use strict;
 use warnings;
 =head1 NAME
@@ -10,7 +8,7 @@ WWW::FetchStory::Fetcher::LiveJournal - fetching module for WWW::FetchStory
 
 =head1 VERSION
 
-version 0.1822
+version 0.1823
 
 =head1 DESCRIPTION
 
@@ -157,7 +155,11 @@ sub extract_story {
     }
 
     my $story = '';
-    if ($content =~ m#<article class="b-singlepost-body"[^>]*>(.*?)<div class="\s*b-singlepost-tags ljtags\s*"#s)
+    if ($content =~ m#<article class="\s*b-singlepost-body[^>]*>(.*?)</article>#s)
+    {
+	$story = $1;
+    }
+    elsif ($content =~ m#<article class="\s*b-singlepost-body[^>]*>(.*?)<div class="\s*b-singlepost-tags ljtags\s*"#s)
     {
 	$story = $1;
     }
@@ -257,6 +259,7 @@ sub extract_story {
     else
     {
 	print STDERR "story not found\n";
+        print STDERR "\n==============\n${content}\n===========\n" if ($self->{debug});
 	return $self->tidy_chars($content);
     }
 
@@ -509,7 +512,7 @@ sub parse_chapter_urls {
 	}
 	else
 	{
-	    while ($content =~ m/<a\s+href="(http:\/\/${user}\.livejournal\.com\/\d+.html")\s*([^>]*)>/sg)
+	    while ($content =~ m/<a\s+href="(http:\/\/${user}\.livejournal\.com\/\d+.html)"\s*([^>]*)>/sg)
 	    {
 		my $ch_url = $1;
                 my $rest = $2;
@@ -519,7 +522,7 @@ sub parse_chapter_urls {
                 }
                 else
                 {
-                    warn "chapter=$ch_url\n" if ($self->{verbose} > 1);
+                    warn "chapter='$ch_url'\n" if ($self->{verbose} > 1);
                     if (!$remember_ch_urls{$ch_url})
                     {
                         push @chapters, "${ch_url}?format=light";
